@@ -1,3 +1,3 @@
 ".onLoad" <- function(libname, pkgname){
-  require("methods")
+  #require("methods")
 }
